# eth2deposit

This folder contains needed parts of [ethereum/eth2.0-deposit-cli](https://github.com/ethereum/eth2.0-deposit-cli) as it's not available on PyPi and can't be set as a dependency in a proper way.
